@@ -29,8 +29,8 @@ def validate_inputs(options: dict):
     if "Term" not in options:
         raise ValidationError("Term is required")
 
-    if "IntRate" not in options:
-        raise ValidationError("IntRate is required")
+    if "IntRate" not in options and "FirstTermRate" not in options:
+        raise ValidationError("IntRate or FirstTermRate is required")
 
     try:
         AccrualCode(options["AccrualCode"])
